@@ -4,14 +4,15 @@ import (
 	"bytes"
 	"context"
 
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/klog"
-	apiregistrationv1 "k8s.io/kube-aggregator/pkg/apis/apiregistration/v1"
+	"k8s.io/klog/v2"
 	apiserviceclient "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset"
 	apiserviceclientv1 "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/typed/apiregistration/v1"
 	apiserviceinformer "k8s.io/kube-aggregator/pkg/client/informers/externalversions"
 	apiservicelister "k8s.io/kube-aggregator/pkg/client/listers/apiregistration/v1"
 
+	"github.com/openshift/library-go/pkg/controller/factory"
 	"github.com/openshift/service-ca-operator/pkg/controller/api"
 )
 
@@ -26,32 +27,34 @@ func newAPIServiceInjectorConfig(config *caBundleInjectorConfig) controllerConfi
 	informers := apiserviceinformer.NewSharedInformerFactory(client, config.defaultResync)
 	informer := informers.Apiregistration().V1().APIServices()
 
-	keySyncer := &apiServiceCABundleInjector{
+	syncer := &apiServiceCABundleInjector{
 		client:   client.ApiregistrationV1().APIServices(),
 		lister:   informer.Lister(),
 		caBundle: config.caBundle,
 	}
 
 	return controllerConfig{
-		name:           "APIServiceCABundleInjector",
-		keySyncer:      keySyncer,
-		informerGetter: informer,
+		name:     "APIServiceCABundleInjector",
+		sync:     syncer.Sync,
+		informer: informer.Informer(),
 		startInformers: func(stopChan <-chan struct{}) {
 			informers.Start(stopChan)
 		},
-		supportedAnnotations: []string{
+		annotationsChecker: annotationsChecker(
 			api.InjectCABundleAnnotationName,
 			api.AlphaInjectCABundleAnnotationName,
-		},
+		),
 	}
 }
 
-func (bi *apiServiceCABundleInjector) Key(namespace, name string) (v1.Object, error) {
-	return bi.lister.Get(name)
-}
+func (bi *apiServiceCABundleInjector) Sync(ctx context.Context, syncCtx factory.SyncContext) error {
+	apiService, err := bi.lister.Get(syncCtx.QueueKey())
+	if apierrors.IsNotFound(err) {
+		return nil
+	} else if err != nil {
+		return err
+	}
 
-func (bi *apiServiceCABundleInjector) Sync(obj v1.Object) error {
-	apiService := obj.(*apiregistrationv1.APIService)
 	if bytes.Equal(apiService.Spec.CABundle, bi.caBundle) {
 		return nil
 	}
@@ -61,6 +64,6 @@ func (bi *apiServiceCABundleInjector) Sync(obj v1.Object) error {
 	// avoid mutating our cache
 	apiServiceCopy := apiService.DeepCopy()
 	apiServiceCopy.Spec.CABundle = bi.caBundle
-	_, err := bi.client.Update(context.TODO(), apiServiceCopy, v1.UpdateOptions{})
+	_, err = bi.client.Update(ctx, apiServiceCopy, v1.UpdateOptions{})
 	return err
 }
